@@ -24,17 +24,17 @@ from redbot.core import app_commands, commands
 from redbot.core.bot import Red
 from redbot.core.config import Config, Group
 from redbot.core.data_manager import cog_data_path
-from redbot.core.utils import chat_formatting as cf
 from redbot.core.utils.views import _ACCEPTABLE_PAGE_TYPES, SimpleMenu
 from redbot_orm.sqlite import register_cog
 from typing_extensions import override
 
 from tidegear import Cog
-from tidegear.exceptions import ConfigurationError, ContextError
+from tidegear import chat_formatting as cf
+from tidegear.exceptions import ConfigurationError, ContextError, NotFoundError
 from tidegear.sentinel.db import Change, Moderation, PartialChannel, PartialGuild, PartialUser
-from tidegear.sentinel.exceptions import HandlerError, LoggedHandlerError
+from tidegear.sentinel.exceptions import HandlerError, LoggedHandlerError, NotReadyError
 from tidegear.sentinel.type import ModerationType, moderation_type_registry
-from tidegear.utils import TimestampStyle, class_overrides_attribute, format_datetime, get_asset_as_file, send_error, set_env, title, truncate_string
+from tidegear.utils import class_overrides_attribute, get_asset_as_file, send_error, set_env, title, truncate_string
 
 
 class SentinelCog(Cog):
@@ -119,6 +119,17 @@ class SentinelCog(Cog):
             self.moderation_type_registry.register(key=moderation_type.key)(moderation_type)
             self._sentinel_logger.verbose("Registered moderation type with key '%s'", moderation_type.key)
 
+        for old, new in self.moderation_type_migrations.items():
+            await Moderation.update({Moderation.type_key: new.key}).where(Moderation.type_key == old)
+
+            guilds = [guild async for guild in self.bot.fetch_guilds() if not await self.bot.cog_disabled_in_guild(self, guild)]
+
+            for guild in guilds:
+                old_config = self.get_type_config(guild, old)
+                new_config = self.get_type_config(guild, new)
+                await new_config.set(await old_config.all())
+                await old_config.clear()
+
         self._sentinel_monitor_expiry_loop.start()
 
     @override
@@ -213,6 +224,25 @@ class SentinelCog(Cog):
         """
         return []
 
+    @property
+    def moderation_type_migrations(self) -> Mapping[str, type[ModerationType]]:
+        """Return a mapping of moderation type keys that should be replaced within the database to new ModerationTypes.
+
+        Migrations will occur on cog load. Please take care to not migrate the types of other cogs utilizing Sentinel unless you expressly want to.
+
+        Example:
+            ```python
+            from sentinel.tidegear import ModerationType
+            from .types import Warn
+
+
+            @property
+            def moderation_type_migrations(self) -> Mapping[str, ModerationType]:
+                return {"warning": Warn}
+            ```
+        """
+        return {}
+
     @property
     def adds_moderation_types(self) -> bool:
         """Check whether or not a cog class overrides the [`moderation_types`][tidegear.sentinel.SentinelCog.moderation_types] method."""
@@ -229,7 +259,7 @@ class SentinelCog(Cog):
         """
         return {name: cog for name, cog in self.bot.cogs.items() if isinstance(cog, SentinelCog)}
 
-    def get_type_config(self, guild: Guild | int, moderation_type: ModerationType | type[ModerationType]) -> Group:
+    def get_type_config(self, guild: Guild | int, moderation_type: ModerationType | type[ModerationType] | str) -> Group:
         """Retrieve a [`Group`][redbot.core.config.Group] that contains configuration for a specific moderation type.
 
         Args:
@@ -237,14 +267,19 @@ class SentinelCog(Cog):
             moderation_type: The moderation type to fetch configuration for.
 
         Returns:
-            The fetched configuration group. Consumed the same was as a `custom()` call.
+            The fetched configuration group. Consumed the same way as a `custom()` call.
         """
         if isinstance(guild, Guild):
             guild_id = guild.id
         else:
             guild_id = guild
 
-        return self.sentinel_config.custom("types", str(guild_id), moderation_type.key)
+        if isinstance(moderation_type, str):
+            key = moderation_type
+        else:
+            key = moderation_type.key
+
+        return self.sentinel_config.custom("types", str(guild_id), key)
 
     async def get_type_config_with_fallback(self, guild: Guild | int, moderation_type: ModerationType, attr: str) -> Any:
         """Retrieve a configuration value for a specific moderation type, falling back to the guild-level config if the type-level config is missing.
@@ -357,23 +392,27 @@ class SentinelCog(Cog):
             await send_error(ctx, content=str(err), ephemeral=True)
             return None
 
+        if silent == MISSING:
+            silent = await self.get_type_config_with_fallback(ctx.guild, moderation_type, "dm_users")
+
         try:
-            moderation = await moderation_handler(ctx=ctx, target=target, **kwargs)
+            if not isinstance(target, (abc.GuildChannel, Thread)):
+                kwargs["silent"] = silent if moderation_type.removes_from_guild else True
+
+            moderation = await moderation_handler(cog=self, ctx=ctx, target=target, **kwargs)
         except HandlerError as err:
-            await send_error(ctx, content=str(err), ephemeral=err.send_error_kwargs.pop("ephemeral", True), **err.send_error_kwargs)
+            await err.send(ctx)
             return None
         except LoggedHandlerError as err:
-            await send_error(ctx, content=str(err), ephemeral=err.send_error_kwargs.pop("ephemeral", True), **err.send_error_kwargs)
-            self._sentinel_logger.exception("Encountered exception within moderation handler %s", moderation_handler)
+            await err.send(ctx)
+            self._sentinel_logger.exception("Encountered exception within moderation handler %s", moderation_handler.__qualname__)
             return None
         except Exception:
             await send_error(ctx, content="Internal error encountered, report this to the bot owner!", ephemeral=True)
-            self._sentinel_logger.exception("Encountered exception within moderation handler %s", moderation_handler)
+            self._sentinel_logger.exception("Encountered exception within moderation handler %s", moderation_handler.__qualname__)
             return None
 
-        if silent == MISSING:
-            silent = await self.get_type_config_with_fallback(ctx.guild, moderation_type, "dm_users")
-        if not silent:
+        if not moderation_type.removes_from_guild and not silent:
             try:
                 await self.contact_target(moderation)
             except (ConfigurationError, TypeError) as err:
@@ -448,8 +487,8 @@ class SentinelCog(Cog):
                 member.id,
                 channel.id if channel else None,
                 guild.id,
-                [name for name, has in resolved_permissions if has],
-                [name for name, wanted in required_permissions if wanted],
+                cf.format_perms_list(resolved_permissions),
+                cf.format_perms_list(required_permissions),
                 missing,
             )
 
@@ -578,7 +617,7 @@ class SentinelCog(Cog):
 
         moderator = await moderation.moderator()
         guild = await (await moderation.guild()).fetch(bot=self.bot)
-        target = await target.fetch(fetcher=guild)
+        target = await target.fetch(fetcher=self.bot, fetch=True)
 
         if channel := next((ch for ch in guild.channels if isinstance(ch, abc.Messageable)), None):
             color = await self.bot.get_embed_color(location=channel)
@@ -598,7 +637,7 @@ class SentinelCog(Cog):
             guild_name = guild.name
 
         if moderation.duration:
-            embed_duration = f" for {cf.humanize_timedelta(timedelta=moderation.duration)}"
+            embed_duration = f" for {cf.humanize_timedelta(moderation.duration)}"
         else:
             embed_duration = ""
 
@@ -725,29 +764,33 @@ class SentinelCog(Cog):
             f"{cf.bold('Target:')} {target.mention if target_in_guild else cf.inline(text=target.name)} ({cf.inline(text=str(target.discord_id))})\n"
             f"{cf.bold('Moderator:')} {moderator.mention if moderator_in_guild else cf.inline(text=moderator.name)} "
             f"({cf.inline(text=str(moderator.discord_id))})\n"
-            f"{cf.bold('Timestamp:')} {format_datetime(dt=moderation.timestamp)} "
-            f"| {format_datetime(dt=moderation.timestamp, style=TimestampStyle.RELATIVE)}"
+            f"{cf.bold('Timestamp:')} {cf.format_datetime(dt=moderation.timestamp)} "
+            f"| {cf.format_datetime(dt=moderation.timestamp, style=cf.TimestampStyle.RELATIVE)}"
         )
 
         if moderation.end_timestamp:
             duration_embed = (
                 (
-                    f"{cf.humanize_timedelta(timedelta=moderation.duration)} "
-                    f"| {format_datetime(dt=moderation.timestamp, style=TimestampStyle.RELATIVE)}"
+                    f"{cf.humanize_timedelta(moderation.duration)} "
+                    f"| {cf.format_datetime(dt=moderation.end_timestamp, style=cf.TimestampStyle.RELATIVE)}"
                 )
                 if not moderation.expired
-                else str(cf.humanize_timedelta(timedelta=moderation.duration))
+                else cf.humanize_timedelta(moderation.duration)
             )
             embed.description += f"\n{cf.bold('Duration:')} {duration_embed}\n{cf.bold('Expired:')} {moderation.expired}"
 
         if moderation.meta:
             for key, value in moderation.meta.items():
-                match key:
-                    case "imported_timestamp":
-                        timestamp = datetime.fromisoformat(value)
-                        embed.description += f"\n{cf.bold(f'{title(key)}:')} {format_datetime(dt=timestamp)}"
-                    case _:
-                        embed.description += f"\n{cf.bold(f'{title(key)}:')} {value}"
+                if key == "imported_timestamp":
+                    timestamp = datetime.fromisoformat(value)
+                    embed.description += f"\n{cf.bold(f'{title(key)}:')} {cf.format_datetime(dt=timestamp)}"
+                else:
+                    try:
+                        if func := moderation.type.history_metadata.get(key, None):
+                            value = func(value)  # noqa: PLW2901
+                    except RegistryKeyError:
+                        pass
+                    embed.description += f"\n{cf.bold(f'{title(key)}:')} {value}"
 
         if moderation.reason:
             embed.add_field(name="Reason", value=cf.box(truncate_string(moderation.reason, 1010)), inline=False)
@@ -762,7 +805,7 @@ class SentinelCog(Cog):
                     value=f"Resolved by {resolver.mention} ({resolver.id}) for:\n" + cf.box(truncate_string(moderation.resolve_reason, 900)),
                     inline=False,
                 )
-            except ValueError:
+            except NotFoundError:
                 pass
         return embed
 
@@ -802,15 +845,15 @@ class SentinelCog(Cog):
                         f"({cf.inline(text=str(moderator.discord_id))})"
                     ),
                     f"{cf.bold('Reason:')} {truncate_string(change.reason, 200)}" if change.reason else "",
-                    f"{cf.bold('Duration:')} {cf.humanize_timedelta(timedelta=change.duration)}" if change.duration else "",
+                    f"{cf.bold('Duration:')} {cf.humanize_timedelta(change.duration)}" if change.duration else "",
                     (
-                        f"{cf.bold('End Timestamp:')} {format_datetime(dt=change.end_timestamp)} "
-                        f"| {format_datetime(dt=change.timestamp, style=TimestampStyle.RELATIVE)}"
+                        f"{cf.bold('End Timestamp:')} {cf.format_datetime(dt=change.end_timestamp)} "
+                        f"| {cf.format_datetime(dt=change.timestamp, style=cf.TimestampStyle.RELATIVE)}"
                     )
                     if change.end_timestamp
                     else "",
-                    f"{cf.bold('Timestamp')} {format_datetime(dt=change.timestamp)} "
-                    f"| {format_datetime(dt=change.timestamp, style=TimestampStyle.RELATIVE)}",
+                    f"{cf.bold('Timestamp')} {cf.format_datetime(dt=change.timestamp)} "
+                    f"| {cf.format_datetime(dt=change.timestamp, style=cf.TimestampStyle.RELATIVE)}",
                 ]
                 copy = change_str.copy()
                 for string in change_str:
@@ -1006,16 +1049,16 @@ class SentinelCog(Cog):
                     f"{cf.bold(text='Moderator:')} {moderator.mention if moderator_in_guild else cf.inline(text=moderator.name)} "
                     f"({cf.inline(text=str(moderator.discord_id))})\n"
                     f"{cf.bold(text='Reason:')} {cf.inline(text=truncate_string(moderation.reason or 'No reason provided.', 140))}\n"
-                    f"{cf.bold(text='Timestamp:')} {format_datetime(dt=moderation.timestamp, style=TimestampStyle.LONG_DATE_AND_TIME)}"
-                    f" | {format_datetime(dt=moderation.timestamp, style=TimestampStyle.RELATIVE)}\n"
+                    f"{cf.bold(text='Timestamp:')} {cf.format_datetime(dt=moderation.timestamp, style=cf.TimestampStyle.LONG_DATE_AND_TIME)}"
+                    f" | {cf.format_datetime(dt=moderation.timestamp, style=cf.TimestampStyle.RELATIVE)}\n"
                 )
 
                 if moderation.duration:
-                    value += f"{cf.bold(text='Duration:')} {cf.humanize_timedelta(timedelta=moderation.duration)}"
+                    value += f"{cf.bold(text='Duration:')} {cf.humanize_timedelta(moderation.duration)}"
                     if moderation.expired:
                         value += " | Expired\n"
                     elif moderation.end_timestamp:
-                        value += f" | {format_datetime(dt=moderation.end_timestamp, style=TimestampStyle.RELATIVE)}\n"
+                        value += f" | {cf.format_datetime(dt=moderation.end_timestamp, style=cf.TimestampStyle.RELATIVE)}\n"
 
                 if moderation.resolved:
                     value += f"{cf.bold(text='Resolved:')} {moderation.resolved}\n"
@@ -1033,8 +1076,9 @@ class SentinelCog(Cog):
 
                 if moderation_type:
                     for key, content in moderation.meta.items():
-                        if key in moderation.type.history_metadata:
-                            value += f"{cf.bold(title(key) + ':')} {content}\n"
+                        if key in moderation.type.history_metadata.keys():
+                            func = moderation.type.history_metadata[key]
+                            value += f"{cf.bold(title(key) + ':')} {func(content)}\n"
 
                 embed.add_field(name=f"Case {moderation.id:,} ({title(moderation.type_key)})", value=value, inline=inline)
             pages.append(embed)
@@ -1048,7 +1092,7 @@ class SentinelCog(Cog):
         moderation_highest = max(moderation_deltas, default=timedelta(0)).total_seconds() * 1_000
 
         self._internal_logger.trace(
-            f"History query completed in {total_ms:,.3f} ms! "
+            f"History query completed in {total_ms:,.3f} ms with {len(moderations):,} moderations retrieved! "
             f"Query construction time: '{query_construction_milliseconds:,.3f} ms' "
             f"Query time: '{query_milliseconds:,.3f} ms' "
             f"Moderation iteration time: '{moderation_milliseconds:,.3f} ms' "
@@ -1081,7 +1125,8 @@ class SentinelCog(Cog):
         moderations = (
             await Moderation.objects()
             .where(
-                Moderation.duration.is_not_null(),
+                Moderation.end_timestamp.is_not_null(),
+                Moderation.end_timestamp <= utcnow(),
                 Moderation.expired.eq(False),
                 Moderation.guild_id.is_in([guild.id for guild in guilds]),
             )
@@ -1105,9 +1150,11 @@ class SentinelCog(Cog):
 
             for moderation in expirable_moderations[guild.id]:
                 try:
-                    await moderation.expire()
+                    await moderation.expire(self)
                     num += 1
-                except ValueError as err:  # noqa: PERF203
+                except NotReadyError:  # noqa: PERF203
+                    pass
+                except ValueError as err:
                     self._sentinel_logger.exception(err)
                     err_num += 1
                 except NotImplementedError as err:
