@@ -2,7 +2,7 @@ from enum import Enum
 
 from piccolo.apps.migrations.auto.migration_manager import MigrationManager
 from piccolo.columns.base import OnDelete, OnUpdate
-from piccolo.columns.column_types import JSON, Boolean, ForeignKey, Integer, Interval, Serial, Text, Timestamptz, Varchar
+from piccolo.columns.column_types import JSON, Boolean, ForeignKey, Integer, Serial, Text, Timestamptz, Varchar
 from piccolo.columns.defaults.timestamptz import TimestamptzNow
 from piccolo.columns.indexes import IndexMethod
 from piccolo.table import Table
@@ -47,8 +47,8 @@ class PartialUser(Table, tablename="partial_user", schema=None):
     )
 
 
-ID = "2025-07-05T17:07:57:946580"
-VERSION = "1.27.1"
+ID = "2025-09-24T04:42:24:416049"
+VERSION = "1.28.0"
 DESCRIPTION = "init"
 
 
@@ -57,13 +57,17 @@ async def forwards():
 
     manager.add_table(class_name="Change", tablename="change", schema=None, columns=None)
 
+    manager.add_table(class_name="Moderation", tablename="moderation", schema=None, columns=None)
+
     manager.add_table(
-        class_name="PartialChannel",
-        tablename="partial_channel",
+        class_name="PartialUser",
+        tablename="partial_user",
         schema=None,
         columns=None,
     )
 
+    manager.add_table(class_name="Table", tablename="table", schema=None, columns=None)
+
     manager.add_table(
         class_name="PartialGuild",
         tablename="partial_guild",
@@ -72,14 +76,12 @@ async def forwards():
     )
 
     manager.add_table(
-        class_name="PartialUser",
-        tablename="partial_user",
+        class_name="PartialChannel",
+        tablename="partial_channel",
         schema=None,
         columns=None,
     )
 
-    manager.add_table(class_name="Moderation", tablename="moderation", schema=None, columns=None)
-
     manager.add_column(
         table_class_name="Change",
         tablename="change",
@@ -218,10 +220,10 @@ async def forwards():
     manager.add_column(
         table_class_name="Change",
         tablename="change",
-        column_name="duration",
-        db_column_name="duration",
-        column_class_name="Interval",
-        column_class=Interval,
+        column_name="end_timestamp",
+        db_column_name="end_timestamp",
+        column_class_name="Timestamptz",
+        column_class=Timestamptz,
         params={
             "default": None,
             "null": True,
@@ -236,303 +238,6 @@ async def forwards():
         schema=None,
     )
 
-    manager.add_column(
-        table_class_name="PartialChannel",
-        tablename="partial_channel",
-        column_name="id",
-        db_column_name="id",
-        column_class_name="Serial",
-        column_class=Serial,
-        params={
-            "null": False,
-            "primary_key": True,
-            "unique": False,
-            "index": True,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialChannel",
-        tablename="partial_channel",
-        column_name="guild_id",
-        db_column_name="guild_id",
-        column_class_name="ForeignKey",
-        column_class=ForeignKey,
-        params={
-            "references": PartialGuild,
-            "on_delete": OnDelete.cascade,
-            "on_update": OnUpdate.cascade,
-            "target_column": None,
-            "null": False,
-            "primary_key": False,
-            "unique": False,
-            "index": False,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialChannel",
-        tablename="partial_channel",
-        column_name="channel_id",
-        db_column_name="channel_id",
-        column_class_name="Integer",
-        column_class=Integer,
-        params={
-            "default": 0,
-            "null": False,
-            "primary_key": False,
-            "unique": False,
-            "index": True,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialChannel",
-        tablename="partial_channel",
-        column_name="last_known_name",
-        db_column_name="last_known_name",
-        column_class_name="Varchar",
-        column_class=Varchar,
-        params={
-            "length": 100,
-            "default": "Unknown Channel",
-            "null": False,
-            "primary_key": False,
-            "unique": False,
-            "index": False,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialChannel",
-        tablename="partial_channel",
-        column_name="last_updated",
-        db_column_name="last_updated",
-        column_class_name="Timestamptz",
-        column_class=Timestamptz,
-        params={
-            "default": TimestamptzNow(),
-            "null": False,
-            "primary_key": False,
-            "unique": False,
-            "index": False,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialGuild",
-        tablename="partial_guild",
-        column_name="id",
-        db_column_name="id",
-        column_class_name="Serial",
-        column_class=Serial,
-        params={
-            "null": False,
-            "primary_key": True,
-            "unique": False,
-            "index": True,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialGuild",
-        tablename="partial_guild",
-        column_name="guild_id",
-        db_column_name="guild_id",
-        column_class_name="Integer",
-        column_class=Integer,
-        params={
-            "default": 0,
-            "null": False,
-            "primary_key": False,
-            "unique": True,
-            "index": True,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialGuild",
-        tablename="partial_guild",
-        column_name="last_known_name",
-        db_column_name="last_known_name",
-        column_class_name="Varchar",
-        column_class=Varchar,
-        params={
-            "length": 100,
-            "default": "Unknown Guild",
-            "null": False,
-            "primary_key": False,
-            "unique": False,
-            "index": False,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialGuild",
-        tablename="partial_guild",
-        column_name="last_updated",
-        db_column_name="last_updated",
-        column_class_name="Timestamptz",
-        column_class=Timestamptz,
-        params={
-            "default": TimestamptzNow(),
-            "null": False,
-            "primary_key": False,
-            "unique": False,
-            "index": False,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialUser",
-        tablename="partial_user",
-        column_name="id",
-        db_column_name="id",
-        column_class_name="Serial",
-        column_class=Serial,
-        params={
-            "null": False,
-            "primary_key": True,
-            "unique": False,
-            "index": True,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialUser",
-        tablename="partial_user",
-        column_name="user_id",
-        db_column_name="user_id",
-        column_class_name="Integer",
-        column_class=Integer,
-        params={
-            "default": 0,
-            "null": False,
-            "primary_key": False,
-            "unique": True,
-            "index": True,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialUser",
-        tablename="partial_user",
-        column_name="last_known_name",
-        db_column_name="last_known_name",
-        column_class_name="Varchar",
-        column_class=Varchar,
-        params={
-            "length": 32,
-            "default": "Unknown User",
-            "null": False,
-            "primary_key": False,
-            "unique": False,
-            "index": False,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialUser",
-        tablename="partial_user",
-        column_name="discriminator",
-        db_column_name="discriminator",
-        column_class_name="Integer",
-        column_class=Integer,
-        params={
-            "default": 0,
-            "null": True,
-            "primary_key": False,
-            "unique": False,
-            "index": False,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
-    manager.add_column(
-        table_class_name="PartialUser",
-        tablename="partial_user",
-        column_name="last_updated",
-        db_column_name="last_updated",
-        column_class_name="Timestamptz",
-        column_class=Timestamptz,
-        params={
-            "default": TimestamptzNow(),
-            "null": False,
-            "primary_key": False,
-            "unique": False,
-            "index": False,
-            "index_method": IndexMethod.btree,
-            "choices": None,
-            "db_column_name": None,
-            "secret": False,
-        },
-        schema=None,
-    )
-
     manager.add_column(
         table_class_name="Moderation",
         tablename="moderation",
@@ -695,16 +400,16 @@ async def forwards():
     manager.add_column(
         table_class_name="Moderation",
         tablename="moderation",
-        column_name="duration",
-        db_column_name="duration",
-        column_class_name="Interval",
-        column_class=Interval,
+        column_name="end_timestamp",
+        db_column_name="end_timestamp",
+        column_class_name="Timestamptz",
+        column_class=Timestamptz,
         params={
             "default": None,
             "null": True,
             "primary_key": False,
             "unique": False,
-            "index": False,
+            "index": True,
             "index_method": IndexMethod.btree,
             "choices": None,
             "db_column_name": None,
@@ -842,4 +547,301 @@ async def forwards():
         schema=None,
     )
 
+    manager.add_column(
+        table_class_name="PartialUser",
+        tablename="partial_user",
+        column_name="id",
+        db_column_name="id",
+        column_class_name="Serial",
+        column_class=Serial,
+        params={
+            "null": False,
+            "primary_key": True,
+            "unique": False,
+            "index": True,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialUser",
+        tablename="partial_user",
+        column_name="user_id",
+        db_column_name="user_id",
+        column_class_name="Integer",
+        column_class=Integer,
+        params={
+            "default": 0,
+            "null": False,
+            "primary_key": False,
+            "unique": True,
+            "index": True,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialUser",
+        tablename="partial_user",
+        column_name="last_known_name",
+        db_column_name="last_known_name",
+        column_class_name="Varchar",
+        column_class=Varchar,
+        params={
+            "length": 32,
+            "default": "Unknown User",
+            "null": False,
+            "primary_key": False,
+            "unique": False,
+            "index": False,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialUser",
+        tablename="partial_user",
+        column_name="discriminator",
+        db_column_name="discriminator",
+        column_class_name="Integer",
+        column_class=Integer,
+        params={
+            "default": 0,
+            "null": True,
+            "primary_key": False,
+            "unique": False,
+            "index": False,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialUser",
+        tablename="partial_user",
+        column_name="last_updated",
+        db_column_name="last_updated",
+        column_class_name="Timestamptz",
+        column_class=Timestamptz,
+        params={
+            "default": TimestamptzNow(),
+            "null": False,
+            "primary_key": False,
+            "unique": False,
+            "index": False,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialGuild",
+        tablename="partial_guild",
+        column_name="id",
+        db_column_name="id",
+        column_class_name="Serial",
+        column_class=Serial,
+        params={
+            "null": False,
+            "primary_key": True,
+            "unique": False,
+            "index": True,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialGuild",
+        tablename="partial_guild",
+        column_name="guild_id",
+        db_column_name="guild_id",
+        column_class_name="Integer",
+        column_class=Integer,
+        params={
+            "default": 0,
+            "null": False,
+            "primary_key": False,
+            "unique": True,
+            "index": True,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialGuild",
+        tablename="partial_guild",
+        column_name="last_known_name",
+        db_column_name="last_known_name",
+        column_class_name="Varchar",
+        column_class=Varchar,
+        params={
+            "length": 100,
+            "default": "Unknown Guild",
+            "null": False,
+            "primary_key": False,
+            "unique": False,
+            "index": False,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialGuild",
+        tablename="partial_guild",
+        column_name="last_updated",
+        db_column_name="last_updated",
+        column_class_name="Timestamptz",
+        column_class=Timestamptz,
+        params={
+            "default": TimestamptzNow(),
+            "null": False,
+            "primary_key": False,
+            "unique": False,
+            "index": False,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialChannel",
+        tablename="partial_channel",
+        column_name="id",
+        db_column_name="id",
+        column_class_name="Serial",
+        column_class=Serial,
+        params={
+            "null": False,
+            "primary_key": True,
+            "unique": False,
+            "index": True,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialChannel",
+        tablename="partial_channel",
+        column_name="guild_id",
+        db_column_name="guild_id",
+        column_class_name="ForeignKey",
+        column_class=ForeignKey,
+        params={
+            "references": PartialGuild,
+            "on_delete": OnDelete.cascade,
+            "on_update": OnUpdate.cascade,
+            "target_column": None,
+            "null": False,
+            "primary_key": False,
+            "unique": False,
+            "index": False,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialChannel",
+        tablename="partial_channel",
+        column_name="channel_id",
+        db_column_name="channel_id",
+        column_class_name="Integer",
+        column_class=Integer,
+        params={
+            "default": 0,
+            "null": False,
+            "primary_key": False,
+            "unique": False,
+            "index": True,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialChannel",
+        tablename="partial_channel",
+        column_name="last_known_name",
+        db_column_name="last_known_name",
+        column_class_name="Varchar",
+        column_class=Varchar,
+        params={
+            "length": 100,
+            "default": "Unknown Channel",
+            "null": False,
+            "primary_key": False,
+            "unique": False,
+            "index": False,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
+    manager.add_column(
+        table_class_name="PartialChannel",
+        tablename="partial_channel",
+        column_name="last_updated",
+        db_column_name="last_updated",
+        column_class_name="Timestamptz",
+        column_class=Timestamptz,
+        params={
+            "default": TimestamptzNow(),
+            "null": False,
+            "primary_key": False,
+            "unique": False,
+            "index": False,
+            "index_method": IndexMethod.btree,
+            "choices": None,
+            "db_column_name": None,
+            "secret": False,
+        },
+        schema=None,
+    )
+
     return manager
