@@ -9,8 +9,6 @@ import inspect
 import os
 import warnings
 from contextlib import contextmanager
-from datetime import datetime
-from enum import StrEnum
 from importlib.resources import as_file, files
 from importlib.util import find_spec
 from typing import TYPE_CHECKING, Any, Callable, Generator
@@ -19,8 +17,8 @@ import discord
 from discord.utils import MISSING
 from red_commons.logging import RedTraceLogger
 from redbot.core import commands
-from redbot.core.utils import chat_formatting as cf
 
+from tidegear import chat_formatting as cf
 from tidegear.constants import FALSE, NONE, TRUE
 from tidegear.metadata import SemVer
 from tidegear.version import version
@@ -159,14 +157,6 @@ def class_overrides_attribute(child: type, parent: type, attribute: str) -> bool
     return child_attr is not parent_attr
 
 
-class_overrides_method = deprecated_alias(
-    new_func=class_overrides_attribute,
-    old_name="class_overrides_method",
-    removal_version=SemVer(major=1, minor=4, patch=0),
-    kwarg_map={"method_name": "attribute"},
-)
-
-
 def get_bool_emoji(value: bool | None) -> str:
     """Return a unicode emoji based on a boolean value.
 
@@ -234,49 +224,6 @@ def title(string: str, /) -> str:
     return string.replace("_", " ").title()
 
 
-class TimestampStyle(StrEnum):
-    """Discord timestamp format options."""
-
-    SHORT_TIME = "t"
-    """`4:45 PM`"""
-    LONG_TIME = "T"
-    """`4:45:33 PM`"""
-    SHORT_DATE = "d"
-    """`7/5/25`"""
-    LONG_DATE = "D"
-    """`July 5th, 2025`"""
-    SHORT_DATE_AND_TIME = "f"
-    """`July 5th, 2025 at 4:45 PM`"""
-    LONG_DATE_AND_TIME = "F"
-    """`Saturday, July 5th, 2025 at 4:45 PM`"""
-    RELATIVE = "R"
-    """`3 minutes ago`"""
-
-
-def format_datetime(dt: datetime, style: TimestampStyle = TimestampStyle.SHORT_DATE_AND_TIME) -> str:
-    """Format a datetime into a Discord-compatible timestamp string.
-
-    Similar to [`discord.utils.format_dt`][], but uses an enum to provide better code readability.
-
-    Example:
-        ```python
-        from discord.utils import utcnow
-        from tidegear.utils import TimestampStyle, format_datetime
-
-        datetime = utcnow()
-        print(format_datetime(dt=datetime, style=TimestampStyle.LONG_DATE_AND_TIME))
-        ```
-
-    Args:
-        dt: The datetime to convert into a Discord timestamp.
-        style: The timestamp style to apply.
-
-    Returns:
-        A string like `<t:1618924800:f>` that Discord will render according to the given style.
-    """
-    return f"<t:{int(dt.timestamp())}:{style}>"
-
-
 async def send_error(
     messeagable: commands.Context | discord.abc.Messageable,
     /,
@@ -287,10 +234,10 @@ async def send_error(
     """Send a message with the content wrapped in an error function.
 
     Args:
-        messeagable: The channel or context to send the message to.
+        messeagable: The context to send the message to.
         content: The content of the message.
         func: The function to use to wrap the message.
-        **kwargs: Additional keyword arguments to pass to `await messeagable.send()`.
+        **kwargs: Additional keyword arguments to pass to [`ctx.send()`][discord.abc.Messeagable.send].
 
     Returns:
         The sent message.
